# ManagedUpstreamIdentityProvider

Managed upstream identity provider
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | Name of the managed upstream identity provider. Ex google | [readonly] 
**enabled** | **bool** | Describes whether the managed upstream identity provider is enabled | [default to False]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


